// NewFileFormatDlg.h
// (c) 2003-2005 exeal

#ifndef _NEW_FILE_FORMAT_DLG_H_
#define _NEW_FILE_FORMAT_DLG_H_
#include "resource.h"
#include "../Manah/Dialog.h"
#include "Ascension\EditDoc.h"	// Ascension::BreakType


namespace Alpha {
	///	uw肵ĐVKv_CAO
	class CNewFileFormatDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_FILENEWWITHFORMAT> {
		// f[^o
	public:
		Ascension::Encodings::CodePage	m_nCodePage;		// R[hy[W
		Ascension::LineBreak			m_lineBreak;		// sR[h
		std::list<std::wstring>			m_documentTypes;	// ^CṽXg
		std::size_t						m_iDocumentType;	// Iꂽ^Cv

		// bZ[Wnh
	protected:
		bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);
		bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);
		void	OnOK();
	};
} // namespace Alpha

#endif /* _NEW_FILE_FORMAT_DLG_H_ */

/* [EOF] */